# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the Fleet Commander."""

__version__ = "1.18.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .artifact_delete import ArtifactDelete
from .artifact_get import ArtifactGet
from .artifact_get_url import ArtifactGetURL
from .artifact_usage_get import ArtifactUsageGet
from .fleet_artifact_sampling_739743 import FleetArtifactSamplingRulesGet
from .fleet_artifact_sampling_a22d2b import FleetArtifactSamplingRulesSet
