# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Browser Service."""

__version__ = "1.18.7"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .models_active_custom_game_response import ModelsActiveCustomGameResponse
from .models_active_matchmaking_game_response import ModelsActiveMatchmakingGameResponse
from .models_add_player_request import ModelsAddPlayerRequest
from .models_add_player_response import ModelsAddPlayerResponse
from .models_admin_session_response import ModelsAdminSessionResponse
from .models_count_active_session_response import ModelsCountActiveSessionResponse
from .models_create_session_request import ModelsCreateSessionRequest
from .models_custom_game_response import ModelsCustomGameResponse
from .models_game_session import ModelsGameSession
from .models_game_session_setting import ModelsGameSessionSetting
from .models_get_session_history_detailed_response_item import (
    ModelsGetSessionHistoryDetailedResponseItem,
)
from .models_get_session_history_search_response_item_v2 import (
    ModelsGetSessionHistorySearchResponseItemV2,
)
from .models_get_session_history_search_response_v2 import (
    ModelsGetSessionHistorySearchResponseV2,
)
from .models_join_game_session_request import ModelsJoinGameSessionRequest
from .models_match_attributes import ModelsMatchAttributes
from .models_match_making import ModelsMatchMaking
from .models_matching_ally import ModelsMatchingAlly
from .models_matching_party import ModelsMatchingParty
from .models_pagination import ModelsPagination
from .models_paging_cursor import ModelsPagingCursor
from .models_party_member import ModelsPartyMember
from .models_recent_player_history import ModelsRecentPlayerHistory
from .models_recent_player_query_response import ModelsRecentPlayerQueryResponse
from .models_server import ModelsServer
from .models_session_by_user_i_ds_response import ModelsSessionByUserIDsResponse
from .models_session_player_history import ModelsSessionPlayerHistory
from .models_session_player_joining import ModelsSessionPlayerJoining
from .models_session_query_response import ModelsSessionQueryResponse
from .models_session_response import ModelsSessionResponse
from .models_status_history import ModelsStatusHistory
from .models_update_session_request import ModelsUpdateSessionRequest
from .models_update_settings_request import ModelsUpdateSettingsRequest
from .response_error import ResponseError
from .restapi_error_response_v2 import RestapiErrorResponseV2
from .restapi_error_v1 import RestapiErrorV1
