# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Leaderboard Service."""

__version__ = "2.29.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_archived_lead_191726 import (
    AdminGetArchivedLeaderboardRankingDataV1Handler,
)
from .create_archived_leaderb_5492e4 import (
    CreateArchivedLeaderboardRankingDataV1Handler,
)
from .delete_user_ranking_admin_v1 import DeleteUserRankingAdminV1
from .delete_user_ranking_by__ed6de1 import DeleteUserRankingByLeaderboardCodeAdminV1
from .delete_user_ranking_public_v1 import DeleteUserRankingPublicV1
from .delete_user_rankings_admin_v1 import DeleteUserRankingsAdminV1
from .get_all_time_leaderboar_d0fb4b import GetAllTimeLeaderboardRankingAdminV1
from .get_all_time_leaderboar_358b23 import GetAllTimeLeaderboardRankingPublicV1
from .get_all_time_leaderboar_9cbcdd import GetAllTimeLeaderboardRankingPublicV2
from .get_archived_leaderboar_c023ea import GetArchivedLeaderboardRankingDataV1Handler
from .get_current_month_leade_26486d import GetCurrentMonthLeaderboardRankingAdminV1
from .get_current_month_leade_4373db import GetCurrentMonthLeaderboardRankingPublicV1
from .get_current_season_lead_a79ffc import GetCurrentSeasonLeaderboardRankingAdminV1
from .get_current_season_lead_51d992 import GetCurrentSeasonLeaderboardRankingPublicV1
from .get_current_week_leader_bdd5ce import GetCurrentWeekLeaderboardRankingAdminV1
from .get_current_week_leader_07d571 import GetCurrentWeekLeaderboardRankingPublicV1
from .get_today_leaderboard_r_2eefd7 import GetTodayLeaderboardRankingAdminV1
from .get_today_leaderboard_r_51cbb5 import GetTodayLeaderboardRankingPublicV1
from .get_user_ranking_admin_v1 import GetUserRankingAdminV1
from .get_user_ranking_public_v1 import GetUserRankingPublicV1
from .update_user_point_admin_v1 import UpdateUserPointAdminV1
