# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "7.16.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .authentication_with_pla_4d2d24 import AuthenticationWithPlatformLinkV3
from .generate_token_by_new_h_af6555 import GenerateTokenByNewHeadlessAccountV3
from .get_country_location_v3 import GetCountryLocationV3
from .logout import Logout
from .platform_authentication_v3 import PlatformAuthenticationV3
from .platform_token_refresh_v3 import PlatformTokenRefreshV3
from .request_one_time_linkin_a9550a import RequestOneTimeLinkingCodeV3
from .request_target_token_re_2a2d5b import RequestTargetTokenResponseV3
from .request_token_by_one_ti_ace4f2 import RequestTokenByOneTimeLinkCodeResponseV3
from .request_token_exchange_code_v3 import RequestTokenExchangeCodeV3
from .request_token_exchange_code_v3 import (
    CodeChallengeMethodEnum as RequestTokenExchangeCodeV3CodeChallengeMethodEnum,
)
from .user_authentication_v3 import UserAuthenticationV3
from .validate_one_time_linki_84d856 import ValidateOneTimeLinkingCodeV3
