# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Ds Artifact Manager."""

__version__ = "1.11.4"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .log_app_message_declaration import LogAppMessageDeclaration
from .models_all_queue_result import ModelsAllQueueResult
from .models_artifact_file_status import ModelsArtifactFileStatus
from .models_list_all_queue_response import ModelsListAllQueueResponse
from .models_list_nodes_ip_address import ModelsListNodesIPAddress
from .models_list_queue_response import ModelsListQueueResponse
from .models_list_terminated_servers_response import ModelsListTerminatedServersResponse
from .models_match_result import ModelsMatchResult
from .models_notif_payload_server_status_change import (
    ModelsNotifPayloadServerStatusChange,
)
from .models_paging_cursor import ModelsPagingCursor
from .models_queue import ModelsQueue
from .models_queue_result import ModelsQueueResult
from .models_request_match_member import ModelsRequestMatchMember
from .models_request_match_party import ModelsRequestMatchParty
from .models_request_matching_ally import ModelsRequestMatchingAlly
from .models_server import ModelsServer
from .models_status_history import ModelsStatusHistory
from .response_error import ResponseError
