# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Lobby Server."""

__version__ = "3.35.5"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .create_notification_tem_590da9 import CreateNotificationTemplateV1Admin
from .create_notification_top_701ddd import CreateNotificationTopicV1Admin
from .create_topic import CreateTopic
from .delete_notification_tem_8c8a06 import DeleteNotificationTemplateSlugV1Admin
from .delete_notification_top_00eb0a import DeleteNotificationTopicV1Admin
from .delete_template_localiz_55eb81 import DeleteTemplateLocalizationV1Admin
from .delete_topic_by_topic_name import DeleteTopicByTopicName
from .free_form_notification__54ba50 import FreeFormNotificationByUserID
from .get_all_notification_te_0053f8 import GetAllNotificationTemplatesV1Admin
from .get_all_notification_to_761be1 import GetAllNotificationTopicsV1Admin
from .get_my_notifications import GetMyNotifications
from .get_notification_topic__b8a441 import GetNotificationTopicV1Admin
from .get_single_template_loc_d01d4b import GetSingleTemplateLocalizationV1Admin
from .get_template_slug_local_385ba4 import GetTemplateSlugLocalizationsTemplateV1Admin
from .get_topic_by_namespace import GetTopicByNamespace
from .get_topic_by_topic_name import GetTopicByTopicName
from .notification_with_templ_f80964 import NotificationWithTemplateByUserID
from .publish_template_locali_b4f377 import PublishTemplateLocalizationV1Admin
from .send_multiple_users_fre_78d5b0 import SendMultipleUsersFreeformNotificationV1Admin
from .send_party_freeform_not_1f36fa import SendPartyFreeformNotificationV1Admin
from .send_party_templated_no_8a9ca4 import SendPartyTemplatedNotificationV1Admin
from .send_specific_user_free_3a173d import SendSpecificUserFreeformNotificationV1Admin
from .send_specific_user_temp_0499f2 import SendSpecificUserTemplatedNotificationV1Admin
from .send_users_freeform_not_3d805f import SendUsersFreeformNotificationV1Admin
from .send_users_templated_no_9d39cc import SendUsersTemplatedNotificationV1Admin
from .update_notification_top_0e4c05 import UpdateNotificationTopicV1Admin
from .update_template_localiz_cc6e6e import UpdateTemplateLocalizationV1Admin
from .update_topic_by_topic_name import UpdateTopicByTopicName
