# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Service."""

__version__ = "3.15.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_delete_user_sessi_e92b87 import AdminDeleteUserSessionStorage
from .admin_read_session_storage import AdminReadSessionStorage
from .admin_read_user_session_f101bc import AdminReadUserSessionStorage
from .public_update_insert_se_f96597 import PublicUpdateInsertSessionStorage
from .public_update_insert_se_4c0538 import PublicUpdateInsertSessionStorageLeader
