# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Gdpr Service."""

__version__ = "2.10.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

# configuration
from .wrappers import admin_get_platform_account_closure_services_configuration
from .wrappers import admin_get_platform_account_closure_services_configuration_async
from .wrappers import admin_get_services_configuration
from .wrappers import admin_get_services_configuration_async
from .wrappers import admin_reset_platform_account_closure_services_configuration
from .wrappers import admin_reset_platform_account_closure_services_configuration_async
from .wrappers import admin_reset_services_configuration
from .wrappers import admin_reset_services_configuration_async
from .wrappers import admin_update_platform_account_closure_services_configuration
from .wrappers import admin_update_platform_account_closure_services_configuration_async
from .wrappers import admin_update_services_configuration
from .wrappers import admin_update_services_configuration_async
from .wrappers import delete_admin_email_configuration
from .wrappers import delete_admin_email_configuration_async
from .wrappers import get_admin_email_configuration
from .wrappers import get_admin_email_configuration_async
from .wrappers import save_admin_email_configuration
from .wrappers import save_admin_email_configuration_async
from .wrappers import update_admin_email_configuration
from .wrappers import update_admin_email_configuration_async

# data_deletion
from .wrappers import admin_cancel_user_account_deletion_request
from .wrappers import admin_cancel_user_account_deletion_request_async
from .wrappers import admin_get_list_deletion_data_request
from .wrappers import admin_get_list_deletion_data_request_async
from .wrappers import admin_get_user_account_deletion_request
from .wrappers import admin_get_user_account_deletion_request_async
from .wrappers import admin_submit_user_account_deletion_request
from .wrappers import admin_submit_user_account_deletion_request_async
from .wrappers import public_cancel_my_account_deletion_request
from .wrappers import public_cancel_my_account_deletion_request_async
from .wrappers import public_cancel_user_account_deletion_request
from .wrappers import public_cancel_user_account_deletion_request_async
from .wrappers import public_get_my_account_deletion_status
from .wrappers import public_get_my_account_deletion_status_async
from .wrappers import public_get_user_account_deletion_status
from .wrappers import public_get_user_account_deletion_status_async
from .wrappers import public_submit_my_account_deletion_request
from .wrappers import public_submit_my_account_deletion_request_async
from .wrappers import public_submit_user_account_deletion_request
from .wrappers import public_submit_user_account_deletion_request_async

# data_retrieval
from .wrappers import admin_cancel_user_personal_data_request
from .wrappers import admin_cancel_user_personal_data_request_async
from .wrappers import admin_generate_personal_data_url
from .wrappers import admin_generate_personal_data_url_async
from .wrappers import admin_get_list_personal_data_request
from .wrappers import admin_get_list_personal_data_request_async
from .wrappers import admin_get_user_personal_data_requests
from .wrappers import admin_get_user_personal_data_requests_async
from .wrappers import admin_request_data_retrieval
from .wrappers import admin_request_data_retrieval_async
from .wrappers import public_cancel_user_personal_data_request
from .wrappers import public_cancel_user_personal_data_request_async
from .wrappers import public_generate_personal_data_url
from .wrappers import public_generate_personal_data_url_async
from .wrappers import public_get_user_personal_data_requests
from .wrappers import public_get_user_personal_data_requests_async
from .wrappers import public_request_data_retrieval
from .wrappers import public_request_data_retrieval_async

# platform_account_closure_client
from .wrappers import admin_delete_platform_account_closure_client
from .wrappers import admin_delete_platform_account_closure_client_async
from .wrappers import admin_get_platform_account_closure_client
from .wrappers import admin_get_platform_account_closure_client_async
from .wrappers import admin_update_platform_account_closure_client
from .wrappers import admin_update_platform_account_closure_client_async

# platform_account_closure_history
from .wrappers import admin_get_user_platform_account_closure_histories
from .wrappers import admin_get_user_platform_account_closure_histories_async
