# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Service."""

__version__ = "3.15.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_player_attributes import AdminGetPlayerAttributes
from .admin_query_player_attributes import AdminQueryPlayerAttributes
from .public_delete_player_at_57835b import PublicDeletePlayerAttributes
from .public_get_bulk_player__da8481 import PublicGetBulkPlayerCurrentPlatform
from .public_get_player_attributes import PublicGetPlayerAttributes
from .public_store_player_attributes import PublicStorePlayerAttributes
